@@ -81,7 +81,7 @@ class OriOptimizeEnv(gym.Env):
         new_obs = np.moveaxis(img, 2, 0)  # 一般输入的图片的通道就是227x227x3, 调整227x227x3的通道为3x227x227
         # 这里会获得一个模型当前角度
         # 这里会修改picture,传递当前的模型旋转的图片信息
-        return {"observation": new_obs.astype(np.float32)}
+        return new_obs.astype(np.float32)
 
     def reset(self, seed=None, return_info=True, options=None):
         """将环境的信息重置，将模型的方向也重置，不重置放进来的模型地址"""
@@ -97,9 +97,9 @@ class OriOptimizeEnv(gym.Env):
         #     self._render_frame()
 
         if not return_info:
-            return observation.items()
+            return observation
         else:
-            return observation.items(), info
+            return observation, info
 
     def step(self, action):
         angle = self._action_to_direction[action]
@@ -112,12 +112,11 @@ class OriOptimizeEnv(gym.Env):
         reward += -0.05 if not terminated else 0  # 如果结束获得奖励，未结束的时候获得的奖励不能为0，应该为负，避免模型停在原地不动
 
         observation = self._get_obs()
-        obs = observation.items()
         info = self._get_info()
 
         print("step forward")
 
-        return obs, reward, terminated, False, info
+        return observation, reward, terminated, False, info
 
     def render(self, mode="human"):
         """对目前来说这个函数没有作用"""
